@@ -1,6 +1,6 @@
 package WWW::Shorten;
 
-use 5.006;
+use 5.008001;
 use strict;
 use warnings;
 
@@ -9,8 +9,7 @@ use Carp ();
 
 our $DEFAULT_SERVICE = 'TinyURL';
 our @EXPORT          = qw(makeashorterlink makealongerlink);
-our $VERSION         = '3.092';
-$VERSION = eval $VERSION;
+our $VERSION = '3.094';
 
 my $style;
 
@@ -41,8 +40,7 @@ WWW::Shorten - Interface to URL shortening sites.
   use warnings;
 
   use WWW::Shorten 'TinyURL'; # Recommended
-  # use WWW::Shorten 'Linkz'; # or one of the others
-  # use WWW::Shorten 'Shorl';
+  # use WWW::Shorten 'Bitly'; # or one of the others
 
   # Individual modules have have their own syntactic variations.
   # See the documentation for the particular module you intend to use for details
@@ -63,7 +61,51 @@ WWW::Shorten - Interface to URL shortening sites.
 A Perl interface to various services that shorten URLs. These sites maintain
 databases of long URLs, each of which has a unique identifier.
 
-=head1 COMMAND LINE PROGRAM
+=head1 DEPRECATION NOTICE
+
+The following shorten services have been deprecated as the endpoints no longer
+exist or function:
+
+=over
+
+=item *
+
+L<WWW::Shorten::LinkToolbot>
+
+=item *
+
+L<WWW::Shorten::Linkz>
+
+=item *
+
+L<WWW::Shorten::MakeAShorterLink>
+
+=item *
+
+L<WWW::Shorten::Metamark>
+
+=item *
+
+L<WWW::Shorten::TinyClick>
+
+=item *
+
+L<WWW::Shorten::Tinylink>
+
+=item *
+
+L<WWW::Shorten::Qurl>
+
+=item *
+
+L<WWW::Shorten::Qwer>
+
+=back
+
+When version C<3.100> is released, these deprecated services will not be part of
+the distribution.
+
+=head1 SHORTEN APP
 
 A very simple program called F<shorten> is supplied in the
 distribution's F<bin> folder. This program takes a URL and
@@ -74,19 +116,10 @@ gives you a shortened version of it.
 Please submit any L<issues|https://github.com/p5-shorten/www-shorten/issues> you
 might have.  We appreciate all help, suggestions, noted problems, and especially patches.
 
-Note that support for extra shortening services should be released as separate modules,
-like L<WWW::Shorten::Googl> or L<WWW::Shorten::Bitly>.
-
-Support for this module is supplied primarily via the using the
-L<GitHub Issues|https://github.com/p5-shorten/www-shorten/issues> but we also
-happily respond to issues submitted to the
-L<CPAN RT|http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Shorten> system via the web
-or email: C<bug-www-shorten@rt.cpan.org>
-
-* https://github.com/p5-shorten/www-shorten/issues
-* http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Shorten
-* ( shorter URL: http://xrl.us/rfb )
-* C<bug-www-shorten@rt.cpan.org>
+* If you know of a shorten service that we don't already have, make your own
+service and release it as a separate module, like L<WWW::Shorten::Googl> or
+L<WWW::Shorten::Bitly>.  Alternatively, you can let us know and we'll be happy
+to work it up for you.
 
 =head1 AUTHOR
 
