@@ -1,11 +1,9 @@
 package WWW::Shorten::Metamark;
 
-use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '3.092';
-$VERSION = eval $VERSION;
+our $VERSION = '3.094';
 
 require WWW::Shorten::_dead;
 
